@@ -1,11 +1,9 @@
 // This file is part of https://github.com/SpringQL/SpringQL which is licensed under MIT OR Apache-2.0. See file LICENSE-MIT or LICENSE-APACHE for full license details.
 
-use serde::{Deserialize, Serialize};
-
 use crate::{pipeline::name::ColumnName, pipeline::relation::sql_type::SqlType};
 
 /// Column with data type.
-#[derive(Clone, Eq, PartialEq, Hash, Debug, Serialize, Deserialize, new)]
+#[derive(Clone, Eq, PartialEq, Hash, Debug, new)]
 pub(crate) struct ColumnDataType {
     column: ColumnName,
     sql_type: SqlType,
