@@ -4,8 +4,7 @@ use super::SelectSyntaxAnalyzer;
 use crate::sql_processor::sql_parser::syntax::GroupingElementSyntax;
 
 impl SelectSyntaxAnalyzer {
-    /// TODO multiple GROUP BY
-    pub(in super::super) fn grouping_element(&self) -> Option<GroupingElementSyntax> {
-        self.select_syntax.grouping_element.clone()
+    pub(in super::super) fn grouping_elements(&self) -> Vec<GroupingElementSyntax> {
+        self.select_syntax.grouping_elements.clone()
     }
 }
