@@ -26,7 +26,10 @@ pub(in crate::sql_processor) struct OptionSyntax {
 pub(in crate::sql_processor) struct SelectStreamSyntax {
     pub(in crate::sql_processor) fields: Vec<SelectFieldSyntax>,
     pub(in crate::sql_processor) from_item: FromItemSyntax,
-    pub(in crate::sql_processor) grouping_element: Option<GroupingElementSyntax>,
+
+    /// Empty when no GROUP BY clause is supplied.
+    pub(in crate::sql_processor) grouping_elements: Vec<GroupingElementSyntax>,
+
     pub(in crate::sql_processor) window_clause: Option<WindowParameter>,
 }
 
