@@ -1,5 +1,7 @@
 // This file is part of https://github.com/SpringQL/SpringQL which is licensed under MIT OR Apache-2.0. See file LICENSE-MIT or LICENSE-APACHE for full license details.
 
+pub use row::SpringValue;
+
 pub(crate) mod row;
 pub(crate) mod task;
 
@@ -160,6 +162,7 @@ impl AutonomousExecutor {
             | SpringError::ThreadPoisoned(_) => log::error!("{:?}", e),
 
             SpringError::InvalidConfig { .. } => unreachable!("must be handled on startup"),
+            SpringError::Null { .. } => unreachable!("must be handled on startup"),
         }
     }
 }
