@@ -4,18 +4,20 @@ use crate::{
     error::Result,
     stream_engine::{
         autonomous_executor::row::value::sql_value::nn_sql_value::NnSqlValue,
-        time::duration::event_duration::EventDuration,
+        time::duration::event_duration::SpringEventDuration,
     },
 };
 
-use super::SqlConvertible;
+use super::{SpringValue, ToNnSqlValue};
 
-impl SqlConvertible for EventDuration {
-    fn into_sql_value(self) -> NnSqlValue {
-        NnSqlValue::Duration(self)
-    }
-
-    fn try_from_duration(v: &EventDuration) -> Result<Self> {
+impl SpringValue for SpringEventDuration {
+    fn try_from_duration(v: &SpringEventDuration) -> Result<Self> {
         Ok(*v)
     }
 }
+
+impl ToNnSqlValue for SpringEventDuration {
+    fn into_sql_value(self) -> NnSqlValue {
+        NnSqlValue::Duration(self)
+    }
+}
