@@ -2,10 +2,8 @@
 
 use std::cmp::Ordering;
 
-use serde::{Deserialize, Serialize};
-
 /// Comparison result of two [SqlValue](crate::SqlValue)s.
-#[derive(Clone, Eq, PartialEq, Hash, Debug, Serialize, Deserialize)]
+#[derive(Clone, Eq, PartialEq, Hash, Debug)]
 pub(crate) enum SqlCompareResult {
     /// v1 = v2
     Eq,
@@ -18,10 +16,6 @@ pub(crate) enum SqlCompareResult {
     /// Only applicable for ordered values.
     GreaterThan,
 
-    /// v1 != v2.
-    /// Only applicable for non-ordered values.
-    NotEq,
-
     /// Either of v1 or v2 is NULL.
     Null,
 }
