@@ -5,9 +5,10 @@ pub(in crate::stream_engine::autonomous_executor) mod source_worker_thread;
 use std::sync::Arc;
 
 use crate::stream_engine::autonomous_executor::{
-    event_queue::EventQueue,
+    args::{Coordinators, EventQueues},
+    main_job_lock::MainJobLock,
     task_executor::task_worker_thread_handler::TaskWorkerThreadArg,
-    worker::worker_handle::{WorkerHandle, WorkerStopCoordinate},
+    worker::worker_handle::WorkerHandle,
 };
 
 use self::source_worker_thread::SourceWorkerThread;
@@ -20,13 +21,15 @@ pub(super) struct SourceWorker {
 
 impl SourceWorker {
     pub(super) fn new(
-        event_queue: Arc<EventQueue>,
-        worker_stop_coordinate: Arc<WorkerStopCoordinate>,
+        main_job_lock: Arc<MainJobLock>,
+        event_queues: EventQueues,
+        coordinators: Coordinators,
         thread_arg: TaskWorkerThreadArg,
     ) -> Self {
         let handle = WorkerHandle::new::<SourceWorkerThread>(
-            event_queue,
-            worker_stop_coordinate,
+            main_job_lock,
+            event_queues,
+            coordinators,
             thread_arg,
         );
         Self { _handle: handle }
