@@ -1,10 +1,8 @@
 // This file is part of https://github.com/SpringQL/SpringQL which is licensed under MIT OR Apache-2.0. See file LICENSE-MIT or LICENSE-APACHE for full license details.
 
-use serde::{Deserialize, Serialize};
-
 use crate::pipeline::name::{ColumnName, StreamName};
 
-#[derive(Clone, Eq, PartialEq, Debug, Serialize, Deserialize, new)]
+#[derive(Clone, Eq, PartialEq, Debug, new)]
 pub(crate) struct InsertPlan {
     stream: StreamName,
     column_order: Vec<ColumnName>,
